@@ -1,5 +1,5 @@
 #
-# $Id: Global.pm 360 2014-11-25 06:50:22Z gomor $
+# $Id: Global.pm 370 2014-12-20 16:50:13Z gomor $
 #
 # core::global Brik
 #
@@ -7,13 +7,13 @@ package Metabrik::Core::Global;
 use strict;
 use warnings;
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 360 $',
+      revision => '$Revision: 370 $',
       tags => [ qw(core main global) ],
       attributes => { 
          device => [ qw(device) ],
@@ -33,9 +33,11 @@ sub brik_properties {
          domainname => [ qw(domainname) ],
          homedir => [ qw(directory) ],
          port => [ qw(port) ],
+         # encoding: see `perldoc Encode::Supported' for other types
          encoding => [ qw(utf8|ascii) ],
          auto_use_on_require => [ qw(0|1) ],
          auto_install_on_require => [ qw(0|1) ],
+         exit_on_sigint => [ qw(0|1) ],
       },
       attributes_default => {
          device => 'eth0',
@@ -58,6 +60,7 @@ sub brik_properties {
          encoding => 'utf8',
          auto_use_on_require => 1,
          auto_install_on_require => 0,
+         exit_on_sigint => 0,
       },
       commands => {
          sleep => [ ],
